summaryrefslogtreecommitdiffstats
path: root/tools/h5repack/h5repack.h
diff options
context:
space:
mode:
authorPedro Vicente Nunes <pvn@hdfgroup.org>2003-12-31 14:00:36 (GMT)
committerPedro Vicente Nunes <pvn@hdfgroup.org>2003-12-31 14:00:36 (GMT)
commit738e808d262a79d43a4697bb731c5d2961a006a2 (patch)
tree64dbf68fe83ebfad007bd655aa0b2536173053e8 /tools/h5repack/h5repack.h
parentee2eecf1b43916925411798297a06bffd39b76f2 (diff)
downloadhdf5-738e808d262a79d43a4697bb731c5d2961a006a2.zip
hdf5-738e808d262a79d43a4697bb731c5d2961a006a2.tar.gz
hdf5-738e808d262a79d43a4697bb731c5d2961a006a2.tar.bz2
[svn-r7999] Purpose:
h5repack new features Description: added support/ tests for contiguous and compact layout processing Solution: Platforms tested: linux solaris AIX Misc. update:
Diffstat (limited to 'tools/h5repack/h5repack.h')
-rw-r--r--tools/h5repack/h5repack.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/tools/h5repack/h5repack.h b/tools/h5repack/h5repack.h
index cee7c1e..16e0f6a 100644
--- a/tools/h5repack/h5repack.h
+++ b/tools/h5repack/h5repack.h
@@ -205,9 +205,10 @@ int check_szip(int rank, /* chunk rank */
int has_layout(hid_t dcpl_id,
pack_info_t *obj);
-int layout_this(const char* name, /* object name from traverse list */
- pack_opt_t *options, /* repack options */
- pack_info_t *pack); /* info about object to apply layout */
+int layout_this(hid_t dcpl_id, /* DCPL from input object */
+ const char* name, /* object name from traverse list */
+ pack_opt_t *options, /* repack options */
+ pack_info_t *pack /*OUT*/) /* object to apply layout */;
int apply_layout(hid_t dcpl_id,
pack_opt_t *options, /* repack options */